/****************************************************************************/
/* Cration du matriel pour la confrence du Club SAS de Qubec 2016-11-01 */ /****************************************************************************/
proc format library = work;
        picture Telephone
            2000000-9999999 = "999-9999"
            other           = "Erreur";

        value f_sexe
            1     = "Homme"
            2     = "Femme"
            3     = "Autre"
            other = "Inconnnu";
run;

data work.Client (drop = _:);
    format N_Client             8.
           Nom_Client         $30.
           Prenom_Client      $30.
           Adresse_Client     $40.
           Ville_Client       $40.
           Code_Postal_Client  $7.;
    do _i_ = 1 to 9;
        n_client = _i_;
        Nom_Client         = "Nom_Client_"     || compress(_i_);
        Prenom_Client      = "Prenom_Client_"  || compress(_i_);
        Adresse_Client     = "Adresse_Client_" || compress(_i_);
        ville_client       = "Ville_Client_"   || compress(_i_);
        Code_postal_Client = "G1P1P"           || compress(_i_);;
        output;
    end;
run;

data work.client_2 (drop = _:);
    format N_Clnt               8.
           Nm_Clnt            $30. 
           Prnm_Clnt          $30.
           Adrss_Clnt         $40.
           Vll_Clnt           $40.
           Code_Postal_Client  $7.;
    do _i_ = 1 to 9;
        N_Clnt = _i_;
        Nm_Clnt            = "Nom_Client_"     || compress(_i_);
        Prnm_Clnt          = "Prenom_Client_"  || compress(_i_);
        Adrss_Clnt         = "Adresse_Client_" || compress(_i_);
        Vll_Clnt           = "Ville_Client_"   || compress(_i_);
        Code_postal_Client = "G1P1P"           || compress(_i_);;
        output;
    end;
run;

data work.province;
    format  Code_Province    $2.
            Abrev_Province   $3.
            Nom_Province_Fr $40.
            Nom_Province_En $40.;
    Code_Province = "QC"; Abrev_Province = "Que"; Nom_Province_Fr = "Qubec";   Nom_Province_En = "Quebec";  output;
    Code_Province = "ON"; Abrev_Province = "Ont"; Nom_Province_Fr = "Ontario";  Nom_Province_En = "Ontario";  output;
    Code_Province = "MB"; Abrev_Province = "Man"; Nom_Province_Fr = "Manitoba"; Nom_Province_En = "Manitoba"; output; run;

** Pour connatre la liste des librairies dont vous avez accs **; proc sql;
    create table work.d_librairies as     
        select  *
        from    dictionary.libnames;
quit;

** Pour produire la liste de toutes les tables disponibles **; proc sql;
    create table work.d_tables as
        select  *
        from    dictionary.tables
        where   libname = "WORK";
quit;

** Pour produire la liste de toutes les colonnes d'une table **; proc sql;
    create table work.d_colonnes as
        select  *
        from    dictionary.columns 
        where   libname = "WORK";
quit;

** Pour produire la liste de tous les formats disponibles dans la session SAS courante **; proc sql;
    create table work.d_formats as
        select  *
        from    dictionary.formats
        where   libname = "WORK";
quit;

/********************************************************************************************/
/* Macro             : Compare_structure                                                    */
/*                                                                                          */
/* Description       : Macro qui va permettre de comparer la structure de deux tables SAS   */
/*                     cte  cte dans une mme table                                      */
/*                                                                                          */
/* Auteur            : Patrice Bourdages                                                    */
/*                                                                                          */
/* Date de cration  : 2015-08-19                                                           */
/*                                                                                          */
/* Paramtres        : Lib_Base        Indique le nom de la librairie dans laquelle se      */
/*                                     trouve la table que l'on dsire utiliser pour la     */
/*                                     base de comparaison                                  */
/*                     Table_Base      Indique le nom de la table SAS que l'on dsire comme */
/*                                     base de comparaison                                  */
/*                     Lib_Compare     Indique le nom de la librairie dans laquelle se      */
/*                                     trouve la table que l'on dsire utiliser pour la     */
/*                                     comparaison                                          */
/*                     Table_Base      Indique le nom de la table SAS que l'on dsire comme */
/*                                     comparaison                                          */
/*                                                                                          */
/* Historique                                                                               */
/*                                                                                          */
/*     Quand      Qui          Description                                                  */
/*     ---------- ------------ -----------------------------------------------------------*/
/*                                                                                          */
/********************************************************************************************/
%macro compare_structure(Lib_Base, Table_Base, Lib_Compare, Table_Compare);
    proc sql;
        create table work.base as
            select  upcase(a.name) as variable,
                    "X" as Base
            from    dictionary.columns as a
            where   libname = upcase("&Lib_Base.") and
                    memname = upcase("&Table_Base.")
            order by 1;
    quit;

    proc sql;
        create table work.compare as
            select  upcase(a.name) as variable,
                    "X" as Compare
            from    dictionary.columns as a
            where   libname = upcase("&Lib_Compare.") and
                    memname = upcase("&Table_Compare.")
            order by 1;
    quit;

    data work.comparaison;
        merge work.base    (in = a)
              work.compare (in = b);
        by variable;
        if a or b;
    run;
%mend compare_structure;

%compare_structure(work, client, work, client_2);

